You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@ambari.apache.org by ak...@apache.org on 2013/11/28 17:53:30 UTC

git commit: AMBARI-3919.When managing configs for a non-default group, the default configs are non-editable but "Remove" button is still there for Custom sections. (akovalenko)

Updated Branches:
  refs/heads/trunk 4de106385 -> b7d29d1cf


AMBARI-3919.When managing configs for a non-default group, the default configs are non-editable but "Remove" button is still there for Custom sections. (akovalenko)


Project: http://git-wip-us.apache.org/repos/asf/ambari/repo
Commit: http://git-wip-us.apache.org/repos/asf/ambari/commit/b7d29d1c
Tree: http://git-wip-us.apache.org/repos/asf/ambari/tree/b7d29d1c
Diff: http://git-wip-us.apache.org/repos/asf/ambari/diff/b7d29d1c

Branch: refs/heads/trunk
Commit: b7d29d1cf5d3369f45c42545081e566be8355f99
Parents: 4de1063
Author: Aleksandr Kovalenko <ol...@ukr.net>
Authored: Thu Nov 28 18:30:07 2013 +0200
Committer: Aleksandr Kovalenko <ol...@ukr.net>
Committed: Thu Nov 28 18:48:58 2013 +0200

----------------------------------------------------------------------
 ambari-web/app/models/service_config.js                         | 5 +++--
 .../main/service/manage_configuration_groups_popup.hbs          | 4 ++--
 2 files changed, 5 insertions(+), 4 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/ambari/blob/b7d29d1c/ambari-web/app/models/service_config.js
----------------------------------------------------------------------
diff --git a/ambari-web/app/templates/main/service/manage_configuration_groups_popup.hbs b/ambari-web/app/templates/main/service/manage_configuration_groups_popup.hbs
index 6484798..4edee0f 100644
--- a/ambari-web/app/templates/main/service/manage_configuration_groups_popup.hbs
+++ b/ambari-web/app/templates/main/service/manage_configuration_groups_popup.hbs
@@ -40,10 +40,10 @@
             </button>
             <ul class="dropdown-menu">
               <li {{bindAttr class="view.isRenameButtonDisabled:disabled"}}>
-                <a  rel="button-info-dropdown" {{bindAttr data-original-title="view.renameButtonTooltip"}} {{action renameConfigGroup target="controller"}}>{{t services.service.config_groups_popup.rename}}</a>
+                <a href="" rel="button-info-dropdown" {{bindAttr data-original-title="view.renameButtonTooltip"}} {{action renameConfigGroup target="controller"}}>{{t services.service.config_groups_popup.rename}}</a>
               </li>
               <li {{bindAttr class="view.isDuplicateButtonDisabled:disabled"}}>
-                <a  rel="button-info-dropdown" {{bindAttr data-original-title="view.duplicateButtonTooltip"}} {{action duplicateConfigGroup target="controller"}}>{{t services.service.config_groups_popup.duplicate}}</a>
+                <a href="" rel="button-info-dropdown" {{bindAttr data-original-title="view.duplicateButtonTooltip"}} {{action duplicateConfigGroup target="controller"}}>{{t services.service.config_groups_popup.duplicate}}</a>
               </li>
             </ul>
           </div>
diff --git a/ambari-web/app/models/service_config.js b/ambari-web/app/models/service_config.js
index c00ac67..a94ee04 100644
--- a/ambari-web/app/models/service_config.js
+++ b/ambari-web/app/models/service_config.js
@@ -191,8 +191,9 @@ App.ServiceConfigProperty = Ember.Object.extend({
   isRemovable: function() {
     var isOriginalSCP = this.get('isOriginalSCP');
     var isUserProperty = this.get('isUserProperty');
-    // Removable when this is a user property, or it is not an original property
-    return isUserProperty || !isOriginalSCP;
+    var isEditable = this.get('isEditable');
+    // Removable when this is a user property, or it is not an original property and it is editable
+    return isEditable && (isUserProperty || !isOriginalSCP);
   }.property('isUserProperty', 'isOriginalSCP'),
   init: function () {
     if(this.get("displayType")=="password"){

http://git-wip-us.apache.org/repos/asf/ambari/blob/b7d29d1c/ambari-web/app/templates/main/service/manage_configuration_groups_popup.hbs
----------------------------------------------------------------------